@@ -23,7 +23,8 @@ class TemplateNotExist(RosTranException):
 
 class TemplateAlreadyExist(RosTranException):
     msg = (
-        'Template "{path}" already exists. Please remove it before transform template.'
+        'Template "{path}" already exists. Please remove it or '
+        "add the '--force' parameter to overwrite it before transform template."
     )
 
 
@@ -35,6 +36,10 @@ class TemplateFormatNotSupport(RosTranException):
     msg = 'Template "{path}"(format: {format}) is not supported.'
 
 
+class InvalidTemplate(RosTranException):
+    msg = "Invalid template. {reason}."
+
+
 class InvalidTemplateFormat(RosTranException):
     msg = 'Template "{path}"(format: {format}) is not valid.'
 
@@ -59,6 +64,14 @@ class InvalidTemplateMetaData(RosTranException):
     msg = "Invalid template meta data. {reason}."
 
 
+class InvalidTemplateRule(RosTranException):
+    msg = "Invalid template rule {name}. {reason}."
+
+
+class InvalidTemplateRules(RosTranException):
+    msg = "Invalid template rules. {reason}."
+
+
 class InvalidTemplateMapping(RosTranException):
     msg = "Invalid template mapping {name}. {reason}."
 
@@ -103,6 +116,10 @@ class InvalidTemplateWorkspace(RosTranException):
     msg = "Invalid template workspace. {reason}."
 
 
+class InvalidYamlTemplateTag(RosTranException):
+    msg = "Invalid yaml template tag. {reason}."
+
+
 class InvalidExcelTemplate(RosTranException):
     msg = "Invalid excel template. {reason}."
 
@@ -161,3 +178,15 @@ class RuleAlreadyExist(RosTranException):
 
 class SystemNotSupport(RosTranException):
     msg = "Current system {name} is not supported."
+
+
+class CloudFormationTransformNotSupported(RosTranException):
+    msg = "CloudFormation transform is not supported."
+
+
+class InvalidTargetPath(RosTranException):
+    msg = "Target path {target_path} is invalid, {reason}"
+
+
+class InvalidTargetFile(RosTranException):
+    msg = "Target file {target_file} is invalid, {reason}"
\ No newline at end of file
